@@ -1,5 +1,5 @@
 /* Easy Publish and Consume Library
- * Copyright (C) 2007  Openismus GmbH
+ * Copyright (C) 2007, 2008  Openismus GmbH
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,14 +18,14 @@
  * Authors:
  *      Mathias Hasselmann
  */
-#include "shell.h"
+#include "libepc/shell.h"
+#include "libepc/i18n.h"
 
 #include <avahi-common/error.h>
 #include <avahi-glib/glib-malloc.h>
 #include <avahi-glib/glib-watch.h>
 
 #include <glib-object.h>
-#include <glib/gi18n-lib.h>
 #include <gmodule.h>
 
 #include <gnutls/gnutls.h>
@@ -452,7 +452,7 @@ epc_shell_progress_update_default (gdouble      progress,
   title = *context;
 
   if (NULL == title)
-    title = _("Progress Changed");
+    title = _("Operation Proceeded");
   if (NULL == message)
     message = _("No details known");
 
